
slice_types = ("cine_sa", "cine_2ch", "cine_3ch", "cine_4ch")

contour_types = (
    "sax_lv_endo",
    "sax_lv_epi",
    "sax_rv",
    "lax_2ch_lv_wall",
    "lax_2ch_lv_vol",
    "lax_2ch_la",
    "lax_3ch_lv_wall",
    "lax_3ch_lv_vol",
    "lax_3ch_rv",
    "lax_4ch_lv_wall",
    "lax_4ch_lv_vol",
    "lax_4ch_rv",
    "lax_4ch_la",
    "lax_4ch_ra",
    "omega_4ch"
)

omega_types = ("omega_4ch", "omega_3ch", "omega_2ch", "omega_sax")

#TODO: omega_3ch_names, omega_2ch_names, omega_sax_names
omega_4ch_names = ("rv_vol", "lv_vol", "ra", "la", "lv_wall")  # now also denotes plotting order

time_format = "%Y/%m/%d, %H:%M:%S"
